testutils

package
v0.0.0-...-1021490 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 7, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package testutils provides utilities for enhanced testing with coverage data organization

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunWithCoverageSubdir

func RunWithCoverageSubdir(t *testing.T, name string, f func(t *testing.T)) bool

RunWithCoverageSubdir runs a subtest with coverage data organized in a subdirectory This demonstrates how we can organize coverage data per test without overlaying the testing package

Types

This section is empty.

Jump to